@@ -131,15 +131,14 @@ impl<C: ColumnBuffer> ColumnarBuffer<C> {
     ///     let mut buffer = buffer_from_description(
     ///         names.len(),
     ///         buffer_description.iter().copied()
-    ///     );
+    ///     ).expect("Must have enough memory available to allocate buffer.");
     ///
     ///     // Fill the buffer with values column by column
-    ///     match buffer.column_mut(0) {
-    ///         AnyColumnViewMut::Text(mut col) => {
-    ///             col.write(names.iter().map(|s| Some(s.as_bytes())))
-    ///         }
-    ///         _ => panic!("We know the name column to hold text.")
-    ///     }
+    ///     let mut col = buffer
+    ///         .column_mut(0)
+    ///         .as_text_view()
+    ///         .expect("We know the name column to hold text.");
+    ///     col.write(names.iter().map(|s| Some(s.as_bytes())));
     ///
     ///     match buffer.column_mut(1) {
     ///         AnyColumnViewMut::I16(mut col) => {
@@ -247,7 +246,7 @@ pub struct ColumnarBuffer<C> {
     columns: Vec<(u16, C)>,
 }
 
-/// A buffer able to be used together with [`ColumnarBuffer`].
+/// A buffer for a single column intended to be used together with [`ColumnarBuffer`].
 ///
 /// # Safety
 ///
@@ -412,7 +411,7 @@ impl TextRowSet {
                 let max_str_len = max_str_len
                     .map(|limit| min(limit, reported_len))
                     .unwrap_or(reported_len);
-                Ok((col_index, TextColumn::new(batch_size, max_str_len)))
+                Ok((col_index, TextColumn::new(batch_size, max_str_len)?))
             })
             .collect::<Result<_, Error>>()?;
         Ok(TextRowSet {
@@ -427,21 +426,21 @@ impl TextRowSet {
     pub fn from_max_str_lens(
         row_capacity: usize,
         max_str_lengths: impl Iterator<Item = usize>,
-    ) -> Self {
+    ) -> Result<Self, Error> {
         let buffers = max_str_lengths
             .enumerate()
             .map(|(index, max_str_len)| {
-                (
+                Ok((
                     (index + 1).try_into().unwrap(),
-                    TextColumn::new(row_capacity, max_str_len),
-                )
+                    TextColumn::new(row_capacity, max_str_len)?,
+                ))
             })
-            .collect();
-        TextRowSet {
+            .collect::<Result<_, _>>()?;
+        Ok(TextRowSet {
             row_capacity,
             num_rows: Box::new(0),
             columns: buffers,
-        }
+        })
     }
 
     /// Access the element at the specified position in the row set.
@@ -523,6 +522,7 @@ mod tests {
             nullable: false,
             kind: BufferKind::I32,
         };
-        buffer_from_description_and_indices(1, [(1, bd), (2, bd), (1, bd)].iter().cloned());
+        buffer_from_description_and_indices(1, [(1, bd), (2, bd), (1, bd)].iter().cloned())
+            .unwrap();
     }
 }
