@@ -1,6 +1,6 @@
 use crate::{
     handles::{CData, CDataMut, HasDataType},
-    DataType,
+    DataType, Error,
 };
 
 use super::{ColumnBuffer, ColumnProjections, Indicator};
@@ -41,15 +41,31 @@ impl<C> TextColumn<C> {
     /// This will allocate a value and indicator buffer for `batch_size` elements. Each value may
     /// have a maximum length of `max_str_len`. This implies that `max_str_len` is increased by
     /// one in order to make space for the null terminating zero at the end of strings.
-    pub fn new(batch_size: usize, max_str_len: usize) -> Self
+    pub fn new(batch_size: usize, max_str_len: usize) -> Result<Self, Error>
     where
         C: Default + Copy,
     {
-        TextColumn {
+        // Use a fallibale allocation for creating the buffer. In applications often the max_len
+        // size of the buffer, might be directly inspired by the maximum size of the type, as
+        // reported, by ODBC. Which might get exceedingly large for types like VARCHAR(MAX)
+
+        // Element size is +1 to account for terminating zero
+        let element_size = max_str_len + 1;
+        let len = element_size * batch_size;
+        let mut values = Vec::new();
+        values
+            .try_reserve_exact(len)
+            .map_err(|_| Error::TooLargeColumnBufferSize {
+                num_elements: batch_size,
+                // We want the element size in bytes
+                element_size: element_size * size_of::<C>(),
+            })?;
+        values.resize(len, C::default());
+        Ok(TextColumn {
             max_str_len,
-            values: vec![C::default(); (max_str_len + 1) * batch_size],
+            values,
             indicators: vec![0; batch_size],
-        }
+        })
     }
 
     /// Bytes of string at the specified position. Includes interior nuls, but excludes the
@@ -88,9 +104,7 @@ impl<C> TextColumn<C> {
         match self.indicator_at(row_index) {
             Indicator::Null => None,
             // Seen no total in the wild then binding shorter buffer to fixed sized CHAR in MSSQL.
-            Indicator::NoTotal => {
-                Some(self.max_str_len)
-            }
+            Indicator::NoTotal => Some(self.max_str_len),
             Indicator::Length(length_in_bytes) => {
                 let length_in_chars = length_in_bytes / size_of::<C>();
                 let length = min(self.max_str_len, length_in_chars);
@@ -284,7 +298,7 @@ impl<C> TextColumn<C> {
     /// Provides access to the raw underlying value buffer. Normal applications should have little
     /// reason to call this method. Yet it may be useful for writing bindings which copy directly
     /// from the ODBC in memory representation into other kinds of buffers.
-    /// 
+    ///
     /// The buffer contains the bytes for every non null valid element, padded to the maximum string
     /// length. The content of the padding bytes is undefined. Usually ODBC drivers write a
     /// terminating zero at the end of each string. For the actual value length call
@@ -392,7 +406,7 @@ impl<'c, C> TextColumnView<'c, C> {
     /// Provides access to the raw underlying value buffer. Normal applications should have little
     /// reason to call this method. Yet it may be useful for writing bindings which copy directly
     /// from the ODBC in memory representation into other kinds of buffers.
-    /// 
+    ///
     /// The buffer contains the bytes for every non null valid element, padded to the maximum string
     /// length. The content of the padding bytes is undefined. Usually ODBC drivers write a
     /// terminating zero at the end of each string. For the actual value length call
@@ -560,7 +574,7 @@ where
     ///     Some(&b"Hello, World!"[..]),
     /// ];
     ///
-    /// let mut buffer = buffer_from_description(input.len(), iter::once(desc));
+    /// let mut buffer = buffer_from_description(input.len(), iter::once(desc)).unwrap();
     ///
     /// buffer.set_num_rows(input.len());
     /// if let AnyColumnViewMut::Text(mut writer) = buffer.column_mut(0) {
@@ -606,7 +620,8 @@ where
     /// }
     ///
     /// # use odbc_api::buffers::CharColumn;
-    /// # let mut buf = CharColumn::new(1, 12);
+    /// # let mut buf = CharColumn::new(1, 12)
+    /// #    .expect("Enough memory to allocate column buffer must be available");
     /// # let mut writer = buf.writer_n(1);
     /// # write_time(&mut writer, 0, 12, 23, 45, 678);
     /// # assert_eq!(
